import java.io.*;
import java.net.*;
import java.security.*;
import javax.crypto.*;

public class AuthenticatorThreadSocketHandler extends Thread {

    private Socket                   socket;
    private AuthenticatorSecrets     as;
    private ObjectInputStream        ois;
    private ObjectOutputStream       oos;
    private RandomFileName           rfn;
    private String                   cipherAlgorithm = "DES/ECB/PKCS5Padding";

    public AuthenticatorThreadSocketHandler(Socket s, AuthenticatorSecrets a,
                                            RandomFileName r) {
        socket = s;
        as = a;
        rfn = r;
    }

    public void init() {
        try {
            oos = new ObjectOutputStream(socket.getOutputStream());
            oos.flush();
            ois = new ObjectInputStream(socket.getInputStream());
        } catch (Exception e) {
            System.err.println("AuthenticatorThreadSocketHandler() Exception-> " + e);
        }
    }

    protected WFMessage verify(WFUserPassMessage w) {
        UPServerPool upsp = new UPServerPool(rfn);
        return upsp.verify(w);
    }

    public void run() {
        init();
        try {
            Cipher cipher = Cipher.getInstance(cipherAlgorithm);
            WFVerification wfv = (WFVerification) ois.readObject();
            cipher.init(Cipher.DECRYPT_MODE, as.getSecretKey(wfv.id));
            WFUserPassMessage wfupm = (WFUserPassMessage) wfv.so.getObject(cipher);

            oos.writeObject(verify(wfupm));
            oos.flush();
        } catch (Exception ex) {
            System.err.println("AuthenticatorThreadSocketHandler: run() Exception-> " + ex);
        }

        try {
            ois.close();
            oos.close();
            socket.close();
        } catch (Exception e) {
            System.err.println("AuthenticatorThreadSocketHandler: run() Exception-> " + e);
        }
    }
}
